wrapped_images.pdf

## Metadata

Title | wrapped_images.pdf
Path | C:\Users\jenni\OneDrive\Documents\Code\burdoc\burdoc\tests\integration\data\inputs\wrapped_images.pdf
Pages | 0
PDF Metadata: format | PDF 1.7
PDF Metadata: title |
PDF Metadata: author | Joe Ennis
PDF Metadata: subject |
PDF Metadata: keywords |
PDF Metadata: creator | Microsoft® Word for Microsoft 365
PDF Metadata: producer | Microsoft® Word for Microsoft 365
PDF Metadata: creationDate | D:20230403060504+01'00'
PDF Metadata: modDate | D:20230403060504+01'00'
PDF Metadata: trapped |
PDF Metadata: encryption |

## Contents

1. Page 0

#### Page 0

Path: | content.0.[0,0].bbox
Type: | addition

Key | Old | New
x1 |  | 523.4120483398438
y1 |  | 101.34558868408203
y0 |  | 73.38560485839844
x0 |  | 72.02400207519531

Path: | content.0.[1,1].bbox
Type: | addition

Key | Old | New
x1 |  | 517.1783447265625
y1 |  | 145.26564025878906
y0 |  | 117.30558776855469
x0 |  | 72.02400207519531

Path: | content.0.[2,2].bbox
Type: | addition

Key | Old | New
x1 |  | 519.4656372070312
y1 |  | 179.22560119628906
y0 |  | 161.2256317138672
x0 |  | 72.02400207519531

Path: | content.0.[7,7].bbox
Type: | addition

Key | Old | New
x1 |  | 195.5
y1 |  | 460.3800048828125
y0 |  | 364.27996826171875
x0 |  | 67.30000305175781

Path: | content.0.[4,4].bbox
Type: | addition

Key | Old | New
x1 |  | 375.263427734375
y1 |  | 267.0955810546875
y0 |  | 219.1855926513672
x0 |  | 72.02400207519531

Path: | content.0.[8,8].bbox
Type: | addition

Key | Old | New
x1 |  | 500.3186950683594
y1 |  | 432.9555969238281
y0 |  | 394.9156188964844
x0 |  | 203.3300018310547

Path: | content.0.[6,6].bbox
Type: | addition

Key | Old | New
x1 |  | 374.6084289550781
y1 |  | 355.05560302734375
y0 |  | 336.93560791015625
x0 |  | 72.02400207519531

Path: | content.0.[9,9].bbox
Type: | addition

Key | Old | New
x1 |  | 290.6992492675781
y1 |  | 480.8356018066406
y0 |  | 472.7956237792969
x0 |  | 72.02400207519531

Lorem ipsum dolor sit amet. 33 distinctio expedita ut recusandae unde sit voluptas perspiciatis ab voluptatem sequi? Eum dignissimos dignissimos et optio rerum eum neque rerum! Est vitae harum ab vitae voluptatem qui iure quia rem voluptas consequatur non corrupti adipisci. Sit pariatur aliquam non iure ducimus est autem dolorem aut ipsum unde qui corrupti labore.

Nam dolores ipsam qui adipisci consequatur et quisquam doloribus 33 omnis itaque sit recusandae atque non adipisci obcaecati sed tempora ipsum. Et galisum ducimus ab iste dolorem sit quia quaerat aut nihil voluptatem ut atque dolore vel praesentium unde a reprehenderit deserunt. Non fuga minima eos nobis quia ut officiis nihil.

Nam distinctio voluptatem At saepe nulla quo fuga autem. Et dicta natus eos rerum dolor ab nemo voluptas ex autem dignissimos ut temporibus dicta.

Lorem ipsum dolor sit amet. 33 distinctio expedita ut recusandae unde sit voluptas perspiciatis ab voluptatem sequi? Eum dignissimos dignissimos et optio rerum eum neque rerum! Est vitae harum ab vitae voluptatem qui iure quia rem voluptas consequatur non corrupti adipisci. Sit pariatur aliquam non iure ducimus est autem dolorem aut ipsum unde qui corrupti labore.

Nam dolores ipsam qui adipisci consequatur et quisquam doloribus 33 omnis itaque sit recusandae atque non adipisci obcaecati sed tempora ipsum. Et galisum ducimus ab iste dolorem sit quia quaerat aut nihil voluptatem ut atque dolore vel praesentium unde a reprehenderit deserunt. Non fuga minima eos nobis quia ut officiis nihil.

Nam distinctio voluptatem At saepe nulla quo fuga autem. Et dicta natus eos rerum dolor ab nemo voluptas ex autem dignissimos ut temporibus dicta.

Nam dolores ipsam qui adipisci consequatur et quisquam doloribus 33 omnis itaque sit recusandae atque non adipisci obcaecati sed tempora ipsum. Et galisum ducimus ab iste dolorem sit quia quaerat aut nihil voluptatem ut atque dolore vel praesentium unde a reprehenderit deserunt. Non fuga minima eos nobis quia ut officiis nihil.

"Old document" by storebukkebruse is licensed under CC BY 2.0.

Lorem ipsum dolor sit amet. 33 distinctio expedita ut recusandae unde sit voluptas perspiciatis ab voluptatem sequi? Eum dignissimos dignissimos et optio rerum eum neque rerum! Est vitae harum ab vitae voluptatem qui iure quia rem voluptas consequatur non corrupti adipisci. Sit pariatur aliquam non iure ducimus est autem dolorem aut ipsum unde qui corrupti labore.

Nam dolores ipsam qui adipisci consequatur et quisquam doloribus 33 omnis itaque sit recusandae atque non adipisci obcaecati sed tempora ipsum. Et galisum ducimus ab iste dolorem sit quia quaerat aut nihil voluptatem ut atque dolore vel praesentium unde a reprehenderit deserunt. Non fuga minima eos nobis quia ut officiis nihil.

Nam distinctio voluptatem At saepe nulla quo fuga autem. Et dicta natus eos rerum dolor ab nemo voluptas ex autem dignissimos ut temporibus dicta.

Lorem ipsum dolor sit amet. 33 distinctio expedita ut recusandae unde sit voluptas perspiciatis ab voluptatem sequi? Eum dignissimos dignissimos et optio rerum eum neque rerum! Est vitae harum ab vitae voluptatem qui iure quia rem voluptas consequatur non corrupti adipisci. Sit pariatur aliquam non iure ducimus est autem dolorem aut ipsum unde qui corrupti labore.

Nam dolores ipsam qui adipisci consequatur et quisquam doloribus 33 omnis itaque sit recusandae atque non adipisci obcaecati sed tempora ipsum. Et galisum ducimus ab iste dolorem sit quia quaerat aut nihil voluptatem ut atque dolore vel praesentium unde a reprehenderit deserunt. Non fuga minima eos nobis quia ut officiis nihil.

Nam distinctio voluptatem At saepe nulla quo fuga autem. Et dicta natus eos rerum dolor ab nemo voluptas ex autem dignissimos ut temporibus dicta.

Nam dolores ipsam qui adipisci consequatur et quisquam doloribus 33 omnis itaque sit recusandae atque non adipisci obcaecati sed tempora ipsum. Et galisum ducimus ab iste dolorem sit quia quaerat aut nihil voluptatem ut atque dolore vel praesentium unde a reprehenderit deserunt. Non fuga minima eos nobis quia ut officiis nihil.

"Old document" by storebukkebruse is licensed under CC BY 2.0.

Parent File Contents